# DMG Wires

A cron-based workflow for processing API data from wire services into post objects.

## Overview

We are registering a new post type called *Wires* whose purpose is to store post objects ingested from various wire services endpoints. We are also introducing an accompanying taxonomy called *Wire Sources* that will reference the source of the post object. For instance, a post object created from the PA Media API will be assigned a Wire Sources term called PA Media.

The workflow is handled by two separate cron tasks. The first is an ingestion task that runs every minute. It will loop through all registered wire services, query their respective endpoint and create new post objects for any article that doesn't exist on the local database. The class for each registered service is required to have a method that checks if an article already exists by looking for a unique identifier in post meta.

The second cron task is a cleanup task. Every day, we will query draft wire posts that are older than 30 days and force delete them. 

## Codebase

Each component of the workflow is handled by a separate class:

### Post_Type

The `dmg_wire` post type is a private post type that can only be managed by users with the `wires_editor` capability. We've enabled REST support so we can view ingested posts in the Gutenberg editor. The post type supports standard `post_tag` and `category` taxonomies, in addition to the custom Wire Sources taxonomy.

### Taxonomy

The `dmg_wire_source` taxonomy is a private, flat taxonomy that can only be managed by users with the `wire_editors` capability.

### Services

The `Services` class is a singleton that keeps a private array of all registered services. We've provided a filter to allow for hooking into this array on the theme level. When the ingestion cron task runs, it loops through the services and calls the respective `ingest_posts` method.

#### The Abstract Service Class

A base class from which all wire service classes can extend from. It mandates the definition of an `ingest_posts` method and has a protected `post_exists` method for determining if an article already exists (effectively, a meta query for the unique identifier stored in `dmg_wires_source_id`).

#### PA_Media

Currently, our only registered service. The `ingest_posts` method queries an endpoint for text assets only (i.e. no audio, video or pictures). We're returned a list of "subjects", which we attempt to map to existing tags and categories.

### Settings

We're registering a settings page that will live under the Wires primary menu item. Each service class can opt in to registering fields on this page by passing the `dmg-wires-settings` page name (for example, if you need a field for storing an API key).

### Cron

Registers the two cron jobs for ingestion and cleanup. The "every minute" interval is not native to core, and thus we need to register it.
