<?php

namespace DMG\Wires;

/**
 * Class Services
 *
 * Register all services
 *
 * @package DMG\Wires
 */
class Services {

    /**
     * Singleton instance
     * 
     * @var \DMG\Wires\Services
     */
    private static $instance = null;

    /**
     * Services
     * 
     * @var array The registered services
     */
    private static $services = array();

    /**
     * Constructor
     */
    private function __construct() {
        add_action( 'init', array( __CLASS__, 'register' ) );
    }

    /**
     * Get singleton instance
     *
     * @return \DMG\Wires\Services instance
     */
    public static function get_instance() {
        if ( is_null( self::$instance ) ) {
            self::$instance = new Services();
        }

        return self::$instance;
    }

    /**
     * Register all services
     */
    public static function register() {

        // Create an array of services native to the plugin (just PA Media for now)
        $services = array(
            new Services\PA_Media(),
            new Services\SWNS(),
        );

        /**
         * Filter the available services
         * 
         * This hook will allow themes to filter and provide their own services
         * that extend from the abstract Service base class
         * 
         * @param array $services
         */
        self::$services = apply_filters( 'dmg_wires_services', $services );
    }

    /**
     * Get all services
     * 
     * @return array All registered services
     */
    public static function get_services() {
        return self::$services;
    }
}

Services::get_instance();
