<?php

namespace DMG\Wires;

/**
 * Class Taxonomy
 *
 * Register a new JSON config editor
 *
 * @package DMG\Wires
 */
class Taxonomy {

	/**
	 * Taxonomy name
	 *
	 * @var string
	 */
	const NAME = 'dmg_wire_source';

	/**
	 * Init
	 */
	public static function init() {
		add_action( 'init', array( __CLASS__, 'register' ) );
		add_action( 'admin_menu', array( __CLASS__, 'remove_submenu_items' ) );
	}

	/**
	 * Register the taxonomy
	 */
	public static function register() {
		register_taxonomy(
			self::NAME,
			Post_Type::NAME,
			array(
				'labels'             => array(
					'name'          => 'Wire Sources',
					'singular_name' => 'Wire Source',
					'menu_name'     => 'Sources',
				),
				'description'        => 'Taxonomy for managing DMG Wire Sources',
				'public'             => false,
				'publicly_queryable' => false,
				'hierarchical'       => false,
				'show_ui'            => true,
				'show_in_menu'       => true,
				'show_in_nav_menus'  => false,
				'show_in_rest'       => true,
				'capabilities'       => array(
					'manage_terms' => 'administrator',
					'edit_terms'   => 'administrator',
					'delete_terms' => 'administrator',
					'assign_terms' => 'administrator',
				),
			)
		);
	}

	/**
	 * Remove Sources submenu item for non-admins
	 */
	public static function remove_submenu_items() {
		if ( ! current_user_can( 'administrator' ) ) {
			remove_submenu_page(
				'edit.php?post_type=' . Post_Type::NAME,
				'edit-tags.php?taxonomy=' . Taxonomy::NAME . '&amp;post_type=' . Post_Type::NAME
			);
		}
	}
}

Taxonomy::init();
