window.addEventListener('DOMContentLoaded', function() {

	const selector = document.querySelector('.dmg-wires__tag-selector');
	const results  = selector.querySelector('.dmg-wires__tag-results');
	const selected = selector.querySelector('.dmg-wires__selected');
	const input    = selector.querySelector('[name="dmg-wires-tag"]');
	const spinner  = selector.querySelector('.spinner');
	const field    = selector.querySelector('input[name="tag"]');
	const template = selector.querySelector('template');

	/**
	 * Debounce helper
	 */
	const debounce = (func, wait, immediate) => {
		let timeout;
		return function() {
			let context = this, args = arguments;
			clearTimeout(timeout);
			timeout = setTimeout(function() {
				timeout = null;
				if (!immediate) func.apply(context, args);
			}, wait);
			if (immediate && !timeout) func.apply(context, args);
		};
	}

	/**
	 * Query tags on key up event
	 * 
	 * @param {Event} The key up event
	 */
	const fetchTags = debounce(function(e) {
		const target = e.target;
		spinner.classList.add('is-active');

		if (target.value.length <= 2) {
			return;
		}

		const path = `/wp/v2/tags/?search=${target.value}`;
		wp.apiRequest({path})
			.then((tags) => {
				outputResults(target, tags)
				spinner.classList.remove('is-active');
			});
	}, 500);


	/**
	 * Output results
	 * 
	 * @param {Element} The text input
	 * @param {Array} The resulting tags
	 */
	const outputResults = function(el, tags) {
		results.innerHTML = '';
		tags.forEach((tag) => {
			const result = document.createElement('span');
			result.innerText = tag.name;
			result.classList.add('dmg-wires__tag-result');
			result.onclick = () => onSelectTag(tag);
			results.append(result);
		});
	};

	/**
	 * Remove a tag
	 * 
	 * @param {Element} The tag to be removed
	 */
	const removeTag = function(el) {
		el.remove();
		selector.classList.remove('dmg-wires__tag-selector--selected');
		field.value = '';
		input.value = '';
		input.focus();
	};

	/**
	 * On tag selection
	 * 
	 * @param {Object} The selected tag
	 */
	const onSelectTag = function(tag) {
		console.log(template.content);
		const clone = template.content.firstElementChild.cloneNode({deep: true});
		clone.querySelector('.dashicons').onclick = () => removeTag(clone);
		clone.querySelector('.dmg-wires__tag-name').innerText = tag.name;
		selector.append(clone);
		field.value = tag.slug;
		input.value = '';
		selector.classList.add('dmg-wires__tag-selector--selected');
		
		results.innerHTML = '';
	}

	// Add event listener
	input.addEventListener('keyup', function(e) {
		fetchTags(e);
	});

	// If a tag is already selected on load, bind the remove handler
	const existingTagRemove = selector.querySelector('.dashicons')
	if (existingTagRemove) {
		existingTagRemove.onclick = () => removeTag(existingTagRemove.closest('.dmg-wires__tag'));
	}
});
