import { subscribe, select, useDispatch } from '@wordpress/data';
import { store as noticesStore } from '@wordpress/notices';
import { Button, Spinner } from '@wordpress/components';
import { useState } from '@wordpress/element';

// Define the container ID for our custom button
const CONTAINER_ID = 'dmg-wires-convert-to-post';

/**
 * Component for Convert to Post button
 */
const ConvertToPost = () => {

	// Loading state
	const [ isSubmitting, setSubmitting ] = useState( false );

	// Click handler
	const onConvertToPost = () => {
		setSubmitting(true);
		window.location.href = `/wp-admin/admin.php?action=dmg_wires_post_conversion&post=${select('core/editor').getCurrentPostId()}&_wpnonce=${DMGWires.nonce}`
	}


	return (
		<>
			{ isSubmitting && 
				<Spinner />
			}
			<Button
				variant="primary"
				onClick={ onConvertToPost }>
				Convert to Post
			</Button>
		</>
	);
}

/**
 * Subscribe to changes so we can add a new button
 */
subscribe( () => {

	// Check if post is ready
	const postId = select('core/editor').getCurrentPostId();
	if ( ! postId ) {
		return;
	}

	// Make sure this isn't a published post
	const status = select('core/editor').getCurrentPostAttribute('status');
	if ( 'publish' === status ) {
		return;
	}

	// See if we've already added the button
	if ( document.getElementById(CONTAINER_ID) ) {
		return;
	}

	// Insert a new component when we can verify that publish button exists
	const publishButton = document.querySelector('.editor-post-publish-button__button');
	if ( publishButton ) {
		const container = document.createElement('div');
		container.id = CONTAINER_ID;
		ReactDOM.render(
			<ConvertToPost />,
			publishButton.parentNode.insertBefore(container, publishButton.nextSibling)
		);
	}
} );
